@@ -18,7 +18,7 @@ Version 0.1
 
 =cut
 
-our $VERSION = '0.1_2';
+our $VERSION = '0.1_4';
 
 =head1 SYNOPSIS
 
@@ -280,18 +280,15 @@ sub jwt {
     return $self->{jwt}
         if !$args{exp} && $self->{jwt_exp} && $self->{jwt_exp} >= time() + 300;
 
-    $args{iat} ||= time();
-    my $old = $self->{jwt_exp} || '-';
-    $self->{jwt_exp} = $args{exp} || (time() + $self->{expiration});
+    return $self->_new_jwt(%args);
+}
 
-    my $ex = $args{exp} || '-';
-    use Carp;
-    my $c = Carp::longmess();
-    my $ln = "";
-    if ($c =~ /simple.t line (\d+)/) {
-        $ln = $1;
-    }
-    warn "$ex $old $self->{jwt_exp} $ln";
+sub _new_jwt {
+    my $self = shift;
+    my %args = @_;
+
+    $args{iat} ||= time();
+    $self->{jwt_exp} = $args{exp} || (time() + $self->{expiration});
 
     my $data = {
         iss => $self->{issuer},
@@ -301,8 +298,7 @@ sub jwt {
     };
 
     $data->{scope} = $self->{scope} if $self->{scope};
-
-    $self->{jwt} = encode_jwt(
+    $self->{jwt}   = encode_jwt(
         payload       => $data,
         alg           => 'ES256',
         key           => $self->{key},
@@ -312,7 +308,7 @@ sub jwt {
         }
     );
 
-    return $self->{jwt};
+    return $self->{jwt}; 
 }
 
 sub _fetch {
